@@ -2219,6 +2219,12 @@ bool ScriptInterp::scrTryeach(void)
 	return true;
 }
 
+bool ScriptInterp::scrError(void)
+{
+	error(getValue("no-arguments"));
+	return true;
+};
+
 bool ScriptInterp::scrUnpack(void)
 {
 	Symbol *sym;
